@@ -71,7 +71,7 @@ class TestGeneralUsage:
             "*---configure",
             "*---unconfigure",
         ])
-        
+
 
     def test_config_preparse_plugin_option(self, testdir):
         testdir.makepyfile(pytest_xyz="""
@@ -294,6 +294,21 @@ class TestGeneralUsage:
         ])
         assert 'sessionstarttime' not in result.stderr.str()
 
+    @pytest.mark.parametrize('lookfor', ['test_fun.py', 'test_fun.py::test_a'])
+    def test_issue134_report_syntaxerror_when_collecting_member(self, testdir, lookfor):
+        testdir.makepyfile(test_fun="""
+            def test_a():
+                pass
+            def""")
+        result = testdir.runpytest(lookfor)
+        result.stdout.fnmatch_lines(['*SyntaxError*'])
+        if '::' in lookfor:
+            result.stderr.fnmatch_lines([
+                '*ERROR*',
+            ])
+            assert result.ret == 4  # usage error only if item not found
+
+
 class TestInvocationVariants:
     def test_earlyinit(self, testdir):
         p = testdir.makepyfile("""
@@ -357,13 +372,13 @@ class TestInvocationVariants:
     @pytest.mark.skipif("sys.version_info < (2,5)")
     def test_python_minus_m_invocation_ok(self, testdir):
         p1 = testdir.makepyfile("def test_hello(): pass")
-        res = testdir.run(py.std.sys.executable, "-m", "py.test", str(p1))
+        res = testdir.run(py.std.sys.executable, "-m", "pytest", str(p1))
         assert res.ret == 0
 
     @pytest.mark.skipif("sys.version_info < (2,5)")
     def test_python_minus_m_invocation_fail(self, testdir):
         p1 = testdir.makepyfile("def test_fail(): 0/0")
-        res = testdir.run(py.std.sys.executable, "-m", "py.test", str(p1))
+        res = testdir.run(py.std.sys.executable, "-m", "pytest", str(p1))
         assert res.ret == 1
 
     @pytest.mark.skipif("sys.version_info < (2,5)")
@@ -490,6 +505,8 @@ class TestDurations:
     source = """
         import time
         frag = 0.02
+        def test_something():
+            pass
         def test_2():
             time.sleep(frag*5)
         def test_1():
