@@ -137,6 +137,48 @@ def test_mark_option(spec, testdir):
     assert len(passed) == len(passed_result)
     assert list(passed) == list(passed_result)
 
+@pytest.mark.multi(spec=[
+        ("interface", ("test_interface",)),
+        ("not interface", ("test_nointer",)),
+])
+def test_mark_option_custom(spec, testdir):
+    testdir.makeconftest("""
+        import pytest
+        def pytest_collection_modifyitems(items):
+            for item in items:
+                if "interface" in item.nodeid:
+                    item.keywords["interface"] = pytest.mark.interface
+    """)
+    testdir.makepyfile("""
+        def test_interface():
+            pass
+        def test_nointer():
+            pass
+    """)
+    opt, passed_result = spec
+    rec = testdir.inline_run("-m", opt)
+    passed, skipped, fail = rec.listoutcomes()
+    passed = [x.nodeid.split("::")[-1] for x in passed]
+    assert len(passed) == len(passed_result)
+    assert list(passed) == list(passed_result)
+
+@pytest.mark.multi(spec=[
+        ("interface", ("test_interface",)),
+        ("not interface", ("test_nointer",)),
+])
+def test_keyword_option_custom(spec, testdir):
+    testdir.makepyfile("""
+        def test_interface():
+            pass
+        def test_nointer():
+            pass
+    """)
+    opt, passed_result = spec
+    rec = testdir.inline_run("-k", opt)
+    passed, skipped, fail = rec.listoutcomes()
+    passed = [x.nodeid.split("::")[-1] for x in passed]
+    assert len(passed) == len(passed_result)
+    assert list(passed) == list(passed_result)
 
 class TestFunctional:
 
@@ -237,6 +279,25 @@ class TestFunctional:
         assert l[1].args == ()
         assert l[2].args == ("pos1", )
 
+    @pytest.mark.xfail(reason='unfixed')
+    def test_merging_markers_deep(self, testdir):
+        # issue 199 - propagate markers into nested classes
+        p = testdir.makepyfile("""
+            import pytest
+            class TestA:
+                pytestmark = pytest.mark.a
+                def test_b(self):
+                    assert True
+                class TestC:
+                    # this one didnt get marked
+                    def test_d(self):
+                        assert True
+        """)
+        items, rec = testdir.inline_genitems(p)
+        for item in items:
+            print (item, item.keywords)
+            assert 'a' in item.keywords
+
     def test_mark_with_wrong_marker(self, testdir):
         reprec = testdir.inline_runsource("""
                 import pytest
@@ -272,7 +333,7 @@ class TestFunctional:
             import pytest
             @pytest.mark.hello("pos1", z=4)
             @pytest.mark.hello("pos0", z=3)
-            def test_func(self):
+            def test_func():
                 pass
         """)
         items, rec = testdir.inline_genitems(p)
@@ -284,6 +345,25 @@ class TestFunctional:
         assert l[0].args == ("pos0",)
         assert l[1].args == ("pos1",)
 
+    def test_keywords_at_node_level(self, testdir):
+        p = testdir.makepyfile("""
+            import pytest
+            @pytest.fixture(scope="session", autouse=True)
+            def some(request):
+                request.keywords["hello"] = 42
+                assert "world" not in request.keywords
+
+            @pytest.fixture(scope="function", autouse=True)
+            def funcsetup(request):
+                assert "world" in request.keywords
+                assert "hello" in  request.keywords
+
+            @pytest.mark.world
+            def test_function():
+                pass
+        """)
+        reprec = testdir.inline_run()
+        reprec.assertoutcome(passed=1)
 
 class TestKeywordSelection:
     def test_select_simple(self, testdir):
@@ -304,9 +384,12 @@ class TestKeywordSelection:
         for keyword in ['test_one', 'est_on']:
             #yield check, keyword, 'test_one'
             check(keyword, 'test_one')
-        check('TestClass.test', 'test_method_one')
+        check('TestClass and test', 'test_method_one')
 
-    def test_select_extra_keywords(self, testdir):
+    @pytest.mark.parametrize("keyword", [
+        'xxx', 'xxx and test_2', 'TestClass', 'xxx and -test_1',
+        'TestClass and test_2', 'xxx and TestClass and test_2'])
+    def test_select_extra_keywords(self, testdir, keyword):
         p = testdir.makepyfile(test_select="""
             def test_1():
                 pass
@@ -318,19 +401,17 @@ class TestKeywordSelection:
             def pytest_pycollect_makeitem(__multicall__, name):
                 if name == "TestClass":
                     item = __multicall__.execute()
-                    item.keywords['xxx'] = True
+                    item.keywords["xxx"] = True
                     return item
         """)
-        for keyword in ('xxx', 'xxx test_2', 'TestClass', 'xxx -test_1',
-                        'TestClass test_2', 'xxx TestClass test_2',):
-            reprec = testdir.inline_run(p.dirpath(), '-s', '-k', keyword)
-            py.builtin.print_("keyword", repr(keyword))
-            passed, skipped, failed = reprec.listoutcomes()
-            assert len(passed) == 1
-            assert passed[0].nodeid.endswith("test_2")
-            dlist = reprec.getcalls("pytest_deselected")
-            assert len(dlist) == 1
-            assert dlist[0].items[0].name == 'test_1'
+        reprec = testdir.inline_run(p.dirpath(), '-s', '-k', keyword)
+        py.builtin.print_("keyword", repr(keyword))
+        passed, skipped, failed = reprec.listoutcomes()
+        assert len(passed) == 1
+        assert passed[0].nodeid.endswith("test_2")
+        dlist = reprec.getcalls("pytest_deselected")
+        assert len(dlist) == 1
+        assert dlist[0].items[0].name == 'test_1'
 
     def test_select_starton(self, testdir):
         threepass = testdir.makepyfile(test_threepass="""
@@ -347,7 +428,6 @@ class TestKeywordSelection:
         item = dlist[0].items[0]
         assert item.name == "test_one"
 
-
     def test_keyword_extra(self, testdir):
         p = testdir.makepyfile("""
            def test_one():
